@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Backup vun der Datebank als SQLite an Zeréckspillen',
-	'dump_slogan' => 'Backup an Zeréckspillen vun der SPIP-Datebank'
-);
+	'dump_slogan' => 'Backup an Zeréckspillen vun der SPIP-Datebank',
+];
